#
# spec file for package xdg-desktop-portal-gtk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xdg-desktop-portal-gtk
Version:        0.10
Release:        lp151.2.3
Summary:        Backend implementation for xdg-desktop-portal using GTK+
License:        LGPL-2.1-or-later
Group:          System/Libraries
Url:            https://github.com/flatpak/xdg-desktop-portal-gtk
# Source is _service generated, git checkout
Source:         %{name}-%{version}.tar.xz
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(xdg-desktop-portal) >= 0.7
# Requires the xdg-desktop-portal service to be available
Requires:       xdg-desktop-portal
Recommends:     %{name}-lang
# Users of gnome-shell and flatpak would enjoy this integration
Supplements:    packageand(gnome-shell:flatpak)
%if 0%{?suse_version} >= 1330
BuildRequires:  pkgconfig(gtk+-wayland-3.0) >= 3.21.5
%endif

%description
A backend implementation for xdg-desktop-portal that is using GTK+ and
various pieces of GNOME infrastructure, such as the org.gnome.Shell.Screenshot
or org.gnome.SessionManager D-Bus interfaces.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}

%files
%license COPYING
%{_libexecdir}/xdg-desktop-portal-gtk
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.gtk.service
%dir %{_datadir}/xdg-desktop-portal
%dir %{_datadir}/xdg-desktop-portal/portals
%{_datadir}/xdg-desktop-portal/portals/gtk.portal
%{_datadir}/applications/xdg-desktop-portal-gtk.desktop
%{_userunitdir}/xdg-desktop-portal-gtk.service

%files lang -f %{name}.lang

%changelog
* Mon Mar  5 2018 fcrozat@suse.com
- Update to version 0.10:
  + Fix critical in file chooser.
  + Add options to screenshot portals.
  + Add screencast and remote portal implementations.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 0.9:
  + Improve the app picker ui.
  + Fix error reporting in the email portal.
  + Updated translations.
* Wed Jul  5 2017 adrien.plazas@suse.com
- Don't use BuildRequires gtk+-wayland-3.0 if the SUSE version is
  below 1330, which prevent any version other than Tumbleweed and
  the upcoming SLE 15 and Leap 15 to have this enabled.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.7:
  + appchooserdialog: Fix CSS loading.
  + Fix desktop file generation.
  + Do not dist generated file xdg-desktop-portal-gtk.desktop.in.
  + Clean and do not distribute generated source files.
  + .gitignore: Add many generated files.
  + .desktop: Tell users to not translate icon name.
  + notification: Fix ::handle-* return values.
  + notification: Fix 'icon' lookup.
  + notification: Use 'app-icon' instead of 'image-path' hint.
  + notification: Support raw data in 'image-data' hint.
  + Fix a bug in the app chooser.
  + Drop UI config.
  + Use a shorter name for apps.
  + Make the heading bigger.
  + Use the filename for the heading.
  + Fully implement the app picker mockup.
  + Update po files.
  + Updated translations.
- Changes from version 0.6:
  + Avoid gtk_label_set_xalign()
  + Avoid G_DECLARE_* macros
  + Avoid gtk_css_provider_load_from_resource()
  + Avoid gtk_entry_grab_focus_without_selecting()
  + Avoid gtk_search_entry_handle_event()
  + Avoid g_autoptr() with GtkPrint types
  + Avoid gtk_print_job_set_source_fd()
  + configure: Update GLib and GTK+ versions
  + appchooserrow: Remove gedit references from UI file
  + appchooserrow: Don't set NULL icons
  + Implement org.freedesktop.impl.portal.Email
  + Update for API changes
  + email: Support thunderbird
  + Add a systemd user unit corresponding to the session service
  + Force the icon size to be 48
  + notification: Add better debug and error messages
  + Encode po/Makevars in UTF-8
  + Some fixes for the filechooser preview
  + Set the program name to a fixed string
  + Redo the app chooser
  + Add an appchooser test
  + Add an empty state
  + Cosmetic changes
  + Make icons 64x64
  + Allow setting the default in testappchooser
  + app chooser: Focus the default choice initially
  + Install a desktop file
  + Fix POFILES
  + Updated translations.
* Sun Jan 22 2017 zaitor@opensuse.org
- Update to version 0.5:
  + build: Add appropriate inclusion paths.
  + Add a preview to the file chooser portal.
  + notification: Support 'non-exported' actions.
  + More work on notifications.
  + Add a simple account portal information.
  + Fix deps for resource generation.
  + AppChooser: Add Wayland transient parent support.
  + Screenshot: Add Wayland transient parent support.
  + Drop an unused include.
  + Print: Add Wayland transient parent support.
  + Account: Add Wayland transient parent support.
  + Access: Add Wayland transient parent support.
  + Revise the account portal ui.
  + Another revision of the account portal ui.
  + Tweak account portal ui one more time.
  + Adapt to API changes in the Account portal.
  + File chooser:
  - Fix the handling of choices.
  - Properly set writable.
  + Add some missing files to EXTRA_DIST.
  + Updated translations.
* Thu Nov  3 2016 dimstar@opensuse.org
- Initial package, version 0.3.
